==> peony-extensions_3.0.2.orig.tar.gz: peony-extensions/peony-extension-computer-view/peony-extension-computer-view_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="146"/>
        <source>You should mount volume first</source>
        <translation>需要首先挂载分区</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>网上邻居</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="54"/>
        <source>Remote</source>
        <translation>远程目录</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="34"/>
        <source>Volume</source>
        <translation>本地分区</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="42"/>
        <source>File System</source>
        <translation>文件系统</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation>连接到服务器</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation>服务器信息</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation>用户信息</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation>标签</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation>用户名</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation>服务端地址</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation>端口</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation>137</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation>138</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation>139</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation>445</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="94"/>
        <source>Connect a server</source>
        <translation>连接远程服务器</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">如sftp://...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="117"/>
        <source>Unmount</source>
        <translation>卸载</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="123"/>
        <source>Eject</source>
        <translation>弹出</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="133"/>
        <location filename="computer-view-container.cpp" line="148"/>
        <source>Property</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="135"/>
        <source>You have to mount this volume first</source>
        <translation>需要首先挂载分区</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>电脑视图</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>显示设备分区, 网络目录和个人目录.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="338"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation>一个或多个程序阻止卸载操作。</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="340"/>
        <source>Unmount failed</source>
        <translation>卸载失败</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="341"/>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation>错误：%1
是否强制卸载？</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="360"/>
        <source>Eject failed</source>
        <translation>弹出失败</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="361"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="362"/>
        <source>Eject Anyway</source>
        <translation>无论如何弹出</translation>
    </message>
</context>
</TS>

==> peony-extensions_3.2.3.orig.tar.gz: peony-extensions/peony-extension-computer-view/peony-extension-computer-view_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="148"/>
        <source>You should mount volume first</source>
        <translation>需要首先挂载分区</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>网上邻居</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="54"/>
        <source>Remote</source>
        <translation>远程目录</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="16"/>
        <source>User Share</source>
        <translation>共享数据</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="39"/>
        <source>Volume</source>
        <translation>本地分区</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="48"/>
        <location filename="computer-view/computer-volume-item.cpp" line="88"/>
        <source>File System</source>
        <translation>文件系统</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation>连接到服务器</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation>服务器信息</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation>用户信息</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation>标签</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation>用户名</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation>服务端地址</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation>端口</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation>137</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation>138</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation>139</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation>445</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="107"/>
        <source>Connect a server</source>
        <translation>连接远程服务器</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">如sftp://...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="128"/>
        <source>Unmount</source>
        <translation>卸载</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="134"/>
        <source>Eject</source>
        <translation>弹出</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="157"/>
        <source>format</source>
        <translation>格式化</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="166"/>
        <location filename="computer-view-container.cpp" line="182"/>
        <source>Property</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="168"/>
        <source>You have to mount this volume first</source>
        <translation>需要首先挂载分区</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>电脑视图</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>显示设备分区, 网络目录和个人目录.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="513"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation>一个或多个程序阻止卸载操作。</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="515"/>
        <location filename="computer-view/computer-volume-item.cpp" line="524"/>
        <location filename="computer-view/computer-volume-item.cpp" line="530"/>
        <source>Unmount failed</source>
        <translation>卸载失败</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="516"/>
        <location filename="computer-view/computer-volume-item.cpp" line="531"/>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation>错误：%1
是否强制卸载？</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="523"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation>无法卸载，您可能需要先关闭一些程序，如分区编辑器等。</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="525"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="560"/>
        <location filename="computer-view/computer-volume-item.cpp" line="581"/>
        <source>Eject failed</source>
        <translation>弹出失败</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="561"/>
        <location filename="computer-view/computer-volume-item.cpp" line="582"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="562"/>
        <location filename="computer-view/computer-volume-item.cpp" line="583"/>
        <source>Eject Anyway</source>
        <translation>无论如何弹出</translation>
    </message>
</context>
</TS>
